@@ -23,19 +23,18 @@ test_that("creating explainer classif", {
     min_rows =  12,
     learn_rate = 0.001
   )
-  explainer <- explain_h2o(model, titanic_test[,1:17], titanic_test[,18])
+  explainer <- explain_h2o(model, titanic_test[,1:17], titanic_test[,18], verbose = FALSE)
   expect_is(explainer, "explainer")
   expect_is(explainer$y_hat, "numeric")
-
+  # h2o::h2o.shutdown(prompt = FALSE)
 })
 
 test_that("creating explainer regr", {
   skip_if_no_java()
   titanic_test <- read.csv(system.file("extdata", "titanic_test.csv", package = "DALEXtra"))
   titanic_train <- read.csv(system.file("extdata", "titanic_train.csv", package = "DALEXtra"))
-  library("DALEX")
-  h2o::h2o.init()
-  h2o::h2o.no_progress()
+  # h2o::h2o.init()
+  # h2o::h2o.no_progress()
   titanic_h2o <- h2o::as.h2o(titanic_train)
   titanic_h2o["survived"] <- h2o::as.factor(titanic_h2o["survived"])
   titanic_test_h2o <- h2o::as.h2o(titanic_test)
@@ -47,20 +46,52 @@ test_that("creating explainer regr", {
     min_rows =  12,
     learn_rate = 0.001
   )
-  explainer <- explain_h2o(model, predict_function = yhat, titanic_test, titanic_test$fare)
+  explainer <- explain_h2o(model, predict_function = yhat, titanic_test, titanic_test$fare, verbose = FALSE)
   expect_is(explainer, "explainer")
   expect_is(explainer$y_hat, "numeric")
-
+  # h2o::h2o.shutdown(prompt = FALSE)
 })
 
+test_that("automl example", {
+  skip_if_no_java()
+  data <- DALEX::titanic_imputed
+
+  # init h2o
+  # h2o::h2o.init()
+
+  # split the data
+  h2o_split <- h2o::h2o.splitFrame(h2o::as.h2o(data))
+  train <- h2o_split[[1]]
+  test <- as.data.frame(h2o_split[[2]])
+
+  # h2o automl takes target as factor
+  train$survived <- h2o::as.factor(train$survived)
+
+  # fit a model
+  automl <- h2o::h2o.automl(y = "survived",
+                            training_frame = train,
+                            max_runtime_secs = 15)
+
+  # stop h2o progress printing
+  h2o::h2o.no_progress()
+
+  # create an explainer for the model
+  explainer <- DALEXtra::explain_h2o(automl,
+                                     data = test,
+                                     y = test$survived,
+                                     label = "h2o", verbose = FALSE)
+
+  expect_is(explainer, "explainer")
+  expect_false(class(explainer$model)=="H2OAutoML")
+  # h2o::h2o.shutdown(prompt = FALSE)
+})
 
 test_that("y is numeric", {
-  skip_if_no_java()
+  #skip_if_no_java()
   titanic_test <- read.csv(system.file("extdata", "titanic_test.csv", package = "DALEXtra"))
   titanic_train <- read.csv(system.file("extdata", "titanic_train.csv", package = "DALEXtra"))
-  library("DALEX")
   h2o::h2o.init()
-  h2o::h2o.no_progress()
+  # h2o::h2o.no_progress()
   titanic_h2o <- h2o::as.h2o(titanic_train)
   titanic_h2o["survived"] <- h2o::as.factor(titanic_h2o["survived"])
   titanic_test_h2o <- h2o::as.h2o(titanic_test)
@@ -73,8 +104,8 @@ test_that("y is numeric", {
     min_rows =  12,
     learn_rate = 0.001
   )
-  explainer <- explain_h2o(model, titanic_test[,1:17], titanic_test_h2o["survived"])
-  expect_is(explainer$y, "numeric")
+  explainer <- explain_h2o(model, titanic_test[,1:17], titanic_test_h2o["survived"], verbose = FALSE)
+  expect_false(class(explainer$y[1]) == "H2OFrame")
   h2o::h2o.shutdown(prompt = FALSE)
 
 })
